# Kata
[![Travis](https://img.shields.io/travis/FlorianKempenich/kata.svg)](https://travis-ci.org/FlorianKempenich/kata) [![PyPI](https://img.shields.io/pypi/v/kata.svg)](https://pypi.org/project/kata/)

Kata: A single command to get a ready to use TDD setup for your Kata, in your language of choice

Templates for all Katas can be found: https://github.com/swkBerlin/kata-bootstraps

### Note
To differenciate between the Repository pattern and a Git/Github repo, the following naming convention has been used:
* `GRepo`: Refers to a Git/Github Repo
* `Repo`: Refers to a repo in the sense of the Repositry pattern (none as of now)


---
## Author Information
Follow me on Twitter: [@ThisIsFlorianK](https://twitter.com/ThisIsFlorianK)  
Find out more about my work: [Florian Kempenich — Personal Website](https://floriankempenich.com)
